@@ -21,13 +21,13 @@ double ERGMM_MCMC_logp_coef_diff(ERGMM_MCMC_Model *model, ERGMM_MCMC_MCMCState *
 double ERGMM_MCMC_logp_REV(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *par, ERGMM_MCMC_Priors *prior);
 double ERGMM_MCMC_logp_REV_diff(ERGMM_MCMC_Model *model, ERGMM_MCMC_MCMCState *cur, ERGMM_MCMC_Priors *prior);
 
-void ERGMM_lp_Y_wrapper(int *n, int *p, int *d,
+void ERGMM_lp_Y_wrapper(int *n, int *p, int *d,	int *latent_eff, int *family, int *res,
 			int *dir, int *viY, double *vdY,
-			int *family, int *iconsts, double *dconsts,
-			int *latent_eff,
+			int *iconsts, double *dconsts,
+
 			double *vX, double *vZ,
 			double *coef,
-			double *sender, double *receiver, int *lock_RE,
+			double *sender, double *receiver,
 			int *vobserved_ties,
 			double *llk);
 
